@@ -1,7 +1,7 @@
 """
 Type annotations for appsync service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/type_defs/)
 
 Usage::
 
@@ -15,6 +15,7 @@ import sys
 from typing import IO, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import (
     ApiCacheStatusType,
@@ -98,20 +99,27 @@ __all__ = (
     "LambdaAuthorizerConfigTypeDef",
     "LambdaConflictHandlerConfigTypeDef",
     "LambdaDataSourceConfigTypeDef",
+    "ListApiKeysRequestListApiKeysPaginateTypeDef",
     "ListApiKeysRequestRequestTypeDef",
     "ListApiKeysResponseTypeDef",
+    "ListDataSourcesRequestListDataSourcesPaginateTypeDef",
     "ListDataSourcesRequestRequestTypeDef",
     "ListDataSourcesResponseTypeDef",
+    "ListFunctionsRequestListFunctionsPaginateTypeDef",
     "ListFunctionsRequestRequestTypeDef",
     "ListFunctionsResponseTypeDef",
+    "ListGraphqlApisRequestListGraphqlApisPaginateTypeDef",
     "ListGraphqlApisRequestRequestTypeDef",
     "ListGraphqlApisResponseTypeDef",
+    "ListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef",
     "ListResolversByFunctionRequestRequestTypeDef",
     "ListResolversByFunctionResponseTypeDef",
+    "ListResolversRequestListResolversPaginateTypeDef",
     "ListResolversRequestRequestTypeDef",
     "ListResolversResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListTypesRequestListTypesPaginateTypeDef",
     "ListTypesRequestRequestTypeDef",
     "ListTypesResponseTypeDef",
     "LogConfigTypeDef",
@@ -815,6 +823,28 @@ LambdaDataSourceConfigTypeDef = TypedDict(
     },
 )
 
+_RequiredListApiKeysRequestListApiKeysPaginateTypeDef = TypedDict(
+    "_RequiredListApiKeysRequestListApiKeysPaginateTypeDef",
+    {
+        "apiId": str,
+    },
+)
+_OptionalListApiKeysRequestListApiKeysPaginateTypeDef = TypedDict(
+    "_OptionalListApiKeysRequestListApiKeysPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListApiKeysRequestListApiKeysPaginateTypeDef(
+    _RequiredListApiKeysRequestListApiKeysPaginateTypeDef,
+    _OptionalListApiKeysRequestListApiKeysPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListApiKeysRequestRequestTypeDef = TypedDict(
     "_RequiredListApiKeysRequestRequestTypeDef",
     {
@@ -846,6 +876,28 @@ ListApiKeysResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListDataSourcesRequestListDataSourcesPaginateTypeDef = TypedDict(
+    "_RequiredListDataSourcesRequestListDataSourcesPaginateTypeDef",
+    {
+        "apiId": str,
+    },
+)
+_OptionalListDataSourcesRequestListDataSourcesPaginateTypeDef = TypedDict(
+    "_OptionalListDataSourcesRequestListDataSourcesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListDataSourcesRequestListDataSourcesPaginateTypeDef(
+    _RequiredListDataSourcesRequestListDataSourcesPaginateTypeDef,
+    _OptionalListDataSourcesRequestListDataSourcesPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListDataSourcesRequestRequestTypeDef = TypedDict(
     "_RequiredListDataSourcesRequestRequestTypeDef",
     {
@@ -877,6 +929,28 @@ ListDataSourcesResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListFunctionsRequestListFunctionsPaginateTypeDef = TypedDict(
+    "_RequiredListFunctionsRequestListFunctionsPaginateTypeDef",
+    {
+        "apiId": str,
+    },
+)
+_OptionalListFunctionsRequestListFunctionsPaginateTypeDef = TypedDict(
+    "_OptionalListFunctionsRequestListFunctionsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListFunctionsRequestListFunctionsPaginateTypeDef(
+    _RequiredListFunctionsRequestListFunctionsPaginateTypeDef,
+    _OptionalListFunctionsRequestListFunctionsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListFunctionsRequestRequestTypeDef = TypedDict(
     "_RequiredListFunctionsRequestRequestTypeDef",
     {
@@ -908,6 +982,14 @@ ListFunctionsResponseTypeDef = TypedDict(
     },
 )
 
+ListGraphqlApisRequestListGraphqlApisPaginateTypeDef = TypedDict(
+    "ListGraphqlApisRequestListGraphqlApisPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListGraphqlApisRequestRequestTypeDef = TypedDict(
     "ListGraphqlApisRequestRequestTypeDef",
     {
@@ -926,6 +1008,29 @@ ListGraphqlApisResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef = TypedDict(
+    "_RequiredListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef",
+    {
+        "apiId": str,
+        "functionId": str,
+    },
+)
+_OptionalListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef = TypedDict(
+    "_OptionalListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef(
+    _RequiredListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef,
+    _OptionalListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListResolversByFunctionRequestRequestTypeDef = TypedDict(
     "_RequiredListResolversByFunctionRequestRequestTypeDef",
     {
@@ -959,6 +1064,29 @@ ListResolversByFunctionResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListResolversRequestListResolversPaginateTypeDef = TypedDict(
+    "_RequiredListResolversRequestListResolversPaginateTypeDef",
+    {
+        "apiId": str,
+        "typeName": str,
+    },
+)
+_OptionalListResolversRequestListResolversPaginateTypeDef = TypedDict(
+    "_OptionalListResolversRequestListResolversPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListResolversRequestListResolversPaginateTypeDef(
+    _RequiredListResolversRequestListResolversPaginateTypeDef,
+    _OptionalListResolversRequestListResolversPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListResolversRequestRequestTypeDef = TypedDict(
     "_RequiredListResolversRequestRequestTypeDef",
     {
@@ -1006,6 +1134,29 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListTypesRequestListTypesPaginateTypeDef = TypedDict(
+    "_RequiredListTypesRequestListTypesPaginateTypeDef",
+    {
+        "apiId": str,
+        "format": TypeDefinitionFormatType,
+    },
+)
+_OptionalListTypesRequestListTypesPaginateTypeDef = TypedDict(
+    "_OptionalListTypesRequestListTypesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListTypesRequestListTypesPaginateTypeDef(
+    _RequiredListTypesRequestListTypesPaginateTypeDef,
+    _OptionalListTypesRequestListTypesPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListTypesRequestRequestTypeDef = TypedDict(
     "_RequiredListTypesRequestRequestTypeDef",
     {
